@@ -1,6 +1,18 @@
 # -*- coding: utf-8 -*-
 def to_text(path):
-    """Wraps Tesseract OCR."""
+    """Wraps Tesseract OCR.
+
+    Parameters
+    ----------
+    path : str
+        path of electronic invoice in JPG or PNG format
+
+    Returns
+    -------
+    extracted_str : str
+        returns extracted text from image in JPG or PNG format
+
+    """
     import subprocess
 
     convert = "convert -density 350 %s -depth 8 tiff:-" % (path)
